@@ -1,4 +1,4 @@
-from django.conf.urls import patterns, include, url
+from django.conf.urls import include, url
 from .views import reactivate_user
 
 app_name = "useraudit"
